#
# testOpenOfficeDoc - OpenOffice.org Document class test
#
# (c) Copyright 2002 by Philipp "philiKON" von Weitershausen
#                       philikon@philikon.de
#
# Released unter the terms of the Mozilla Public License (MPL) v1.1
#
# Please see README.txt for further information
#

"""
OpenOffice.org Document class test

$Id: testOpenOfficeDoc.py,v 1.2 2002/11/16 10:41:43 philipp Exp $
"""

import os, sys, unittest
from types import DictType, StringType
from zipfile import BadZipfile
from StringIO import StringIO

from Products.ZooDocument.OpenOfficeDoc import OpenOfficeDoc
from Products.ZooDocument.IOfficeDocument import IOfficeDocument

execfile( os.path.join( sys.path[0], "framework.py" ) )


class OpenOfficeDocTest( unittest.TestCase ):

    def setUp( self ):
        filename = os.path.join( os.path.dirname(__file__), "test.sxw" )
        testfile = open( filename )
        self.doc = OpenOfficeDoc( testfile )

    def tearDown( self ):
        pass

    def testNoZipFile( self ):
        not_a_zip_file = StringIO("")
        self.assertRaises( BadZipFile, OpenOfficeDoc(not_a_zip_file) )

    def testInterface( self ):
        assert IOfficeDocument.isImplementedBy( self.doc )

    def testDocType( self ):
        self.assertEqual( self.doc.getDocType(), "text" )

    def testMetaData( self ):
        # checking that the meta data is returned as a dict
        # is the most we can do since the keys can vary.
        self.assertEqual( type( self.doc.getMetaData() ), DictType )

    def testGetFile( self ):
        doc = self.doc
        self.assertEqual( type( doc.getFile( "context.xml" ) ), StringType )
        self.assertEqual( type( doc.getFile( "meta.xml" ) ), StringType )
        self.assertEqual( type( doc.getFile( "settings.xml" ) ), StringType )
        self.assertEqual( type( doc.getFile( "styles.xml" ) ), StringType )
        self.assertRaises( KeyError, doc.getFile( "non_existant_file" ) )

    def testGetFiles( self ):
        doc = self.doc
        seq = ["context.xml", "meta.xml", "settings.xml", "styles.xml", "META-INF/manifest.xml"]
        pat = "*xml"
        self.assertEqual( doc.getFiles(seq), doc.getFiles(pat) )
            
    def testGetPictures( self ):
        pictures = self.doc.getPictures()
        self.assertEqual( type(pictures), DictType )
        self.assertEqual( len(pictures.keys()), 1 )

framework()

